using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public partial class Calendar : System.Web.UI.Page
{
  protected void Page_Load(object sender, EventArgs e)
  {
		if (!Page.IsPostBack)
		{
			string selected = Request.QueryString["selected"].ToString();
			string id = Request.QueryString["id"].ToString();

			Cal.FirstDayOfWeek = FirstDayOfWeek.Default;

			// Select the Correct date for Calendar from query string
			// If fails, pick the current date on Calendar
			try
			{
				Cal.SelectedDate = Convert.ToDateTime(selected);
				Cal.VisibleDate = Convert.ToDateTime(selected);
			}
			catch
			{
				Cal.SelectedDate = DateTime.Today;
				Cal.VisibleDate = DateTime.Today;
			}

			// Fills in correct values for the dropdown menus
			FillCalendarChoices();
			SelectCorrectValues();

			// Add JScript to the OK button so that when the user clicks on it, the selected date
			// is passed back to the calling page.
			OKButton.Attributes.Add("onClick", "window.opener.SetDate('" + id + "', document.forms[0].datechosen.value);return(false);");
			CancelButton.Attributes.Add("onClick", "CloseWindow()");
		}
	}

	//***************************************************************
	//
	// FillCalendarChoices method is used to fill dropdowns with month and year values 
	// 
	//***************************************************************

	private void FillCalendarChoices()
	{
		DateTime thisdate = new DateTime(DateTime.Today.Year, 1, 1);

		// Fills in month values
		for (int x = 0; x <= 11; x++)
		{
			// Loops through 12 months of the year and fills in each month value
			ListItem li = new ListItem(thisdate.ToString("MMMM"), thisdate.Month.ToString());
			MonthSelect.Items.Add(li);
			thisdate = thisdate.AddMonths(1);
		}

		// Fills in year values and change y value to other years if necessary

		for (int y = 1920; y <= thisdate.Year + 30; y++)
			YearSelect.Items.Add(y.ToString());
	}


	//***************************************************************************
	//
	// The SelectCorrectValues method is used to select the correct values in dropdowns 
	// according to the selected date on Calendar
	//
	//***************************************************************************

	private void SelectCorrectValues()
	{
		lblDate.Text = Cal.SelectedDate.ToShortDateString();
		datechosen.Value = lblDate.Text;
		MonthSelect.SelectedIndex = MonthSelect.Items.IndexOf(MonthSelect.Items.FindByValue(Cal.SelectedDate.Month.ToString()));
		YearSelect.SelectedIndex = YearSelect.Items.IndexOf(YearSelect.Items.FindByValue(Cal.SelectedDate.Year.ToString()));
	}

	protected void Cal_SelectionChanged(object sender, System.EventArgs e)
	{
		Cal.VisibleDate = Cal.SelectedDate;
		SelectCorrectValues();
	}

	protected void MonthSelect_SelectedIndexChanged(object sender, System.EventArgs e)
	{
		Cal.VisibleDate = new DateTime(Convert.ToInt32(YearSelect.SelectedItem.Value), Convert.ToInt32(MonthSelect.SelectedItem.Value), 1);
		Cal.SelectedDate = Cal.VisibleDate;
		SelectCorrectValues();
	}

	protected void YearSelect_SelectedIndexChanged(object sender, System.EventArgs e)
	{
		Cal.VisibleDate = new DateTime(Convert.ToInt32(YearSelect.SelectedItem.Value), Convert.ToInt32(MonthSelect.SelectedItem.Value), 1);
		Cal.SelectedDate = Cal.VisibleDate;
		SelectCorrectValues();
	}

}
