using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using System.Configuration;
using System.Data.OleDb;

namespace AxpDBNetCSSample.Samples
{
	/// <summary>
	/// Summary description for Sample21b.
	/// </summary>
	public class Sample21b : System.Web.UI.Page
	{
		protected Axezz.WebControls.AxpDataGrid AxpDataGrid1;

		private bool isInputValid = true;

		/// <summary>
		/// 3 test types on this page	
		/// </summary>
		private enum TestTypes
		{
			SQLCommand,
			ManualDataSource,
			StoredProcedure,
		}										 

		/// <summary>
		/// >>>>>>>>>> Change testype here if needed <<<<<<<<<<<<<<
		/// </summary>
		private TestTypes testType = TestTypes.ManualDataSource;

		private string connectionString;

		// CREATE DATABASE Objects in Sql Server before testing this page.
		// 
		// Remove the comments and run in a SQL window:
		//
		// CREATE TABLE dbo.titles
		// (
		//    title_id  int         IDENTITY (1, 1) NOT NULL     CONSTRAINT PKtitleid PRIMARY KEY CLUSTERED,
		//    title     varchar(80) NULL,
		//    pub_id    char(4)     NULL,
		//    anumber   int         NULL
		// )
		// GO
		// 
		// CREATE PROCEDURE dbo.GetTitles
		//   @title_id int
		// as
		// if @title_id = -1
		// 	select * From titles
		// else
		// 	select * From titles where title_id=@title_id
		// GO	

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.AxpDataGrid1.UpdateClick += new System.EventHandler(this.AxpDataGrid1_UpdateClick);
			this.AxpDataGrid1.DeleteClick += new System.EventHandler(this.AxpDataGrid1_DeleteClick);
			this.AxpDataGrid1.InsertClick += new System.EventHandler(this.AxpDataGrid1_InsertClick);
			this.AxpDataGrid1.BeforeFormEditRender += new Axezz.WebControls.AxpDataGrid.BeforeFormEditRenderEventHandler(this.AxpDataGrid1_BeforeFormEditRender);
			this.Load += new System.EventHandler(this.Page_Load);
			this.PreRender += new System.EventHandler(this.Page_PreRender);

		}
		#endregion

		private void Page_Load(object sender, System.EventArgs e)
		{
			// Make sure to use an OleDb connection string (AxpDataGrid requires it, and we use OleDb for convenience in our custom routines below too.
			connectionString = ConfigurationSettings.AppSettings["ConnectionString"];			

			AxpDataGrid1.EditOptions = "ALL NOVIEW";
			AxpDataGrid1.UseDataBinding = true;		// Important, DataBind called in PreRender
			AxpDataGrid1.EditPerformUpdates = false;		// We are doing our own database update 

			// Since editing is needed we MUST always provide a connection string
			// AND commands for the Edit Form, even if they are not used for Update,Insert and Delete
			AxpDataGrid1.ConnectionString = connectionString;
			AxpDataGrid1.EditSQL = "Select * from titles";
			AxpDataGrid1.DeleteSQL = "Delete From titles";
			AxpDataGrid1.EditPrimaryKeys = "title_id";
			AxpDataGrid1.EditNewPKStatement = "autoincrement";

			// Display options
			AxpDataGrid1.RowRollOverEffect = true;
			AxpDataGrid1.RowClickAction = "openform";
			AxpDataGrid1.DisplayNavBar = "both";

			// Set initial datasource to all records
			SetDataSource("");
		}

		/// <summary>
		/// Grid databinding is done in Page PreRender to ensure that we call it only once
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void Page_PreRender(object sender, System.EventArgs e)
		{
			AxpDataGrid1.DataBind();
		}

		private void SetDataSource(string pk)
		{
			// -------------------------------------------------
			// Tests for 3 different Grid datasource approaches
			// -------------------------------------------------

			// -------------------------------------------------
			// sqlCmd used for manual datasource and SQL command
			// -------------------------------------------------
			string sqlCmd = "SELECT * FROM titles";
			if (pk != String.Empty)
				sqlCmd += " WHERE title_id=" + pk;		

			switch (testType)
			{
				case TestTypes.SQLCommand:
					// -------------------------------------------------
					// >>> TEST 1. SQL command.
					// -------------------------------------------------
					AxpDataGrid1.SQL = sqlCmd;
					break;
			
				case TestTypes.ManualDataSource:
					// -------------------------------------------------
					// >>> TEST 2. Manual DataSource.
					// -------------------------------------------------
					OleDbDataAdapter da = new OleDbDataAdapter(sqlCmd, connectionString);
					DataTable dt = new DataTable();
					da.Fill(dt);
					AxpDataGrid1.DataSource = dt;
					break;
			
				case TestTypes.StoredProcedure:
					// -------------------------------------------------
					// >>> TEST 3. Sql Server Stored Procedure. 
					// -------------------------------------------------

					// AxpDataGrid does not support setting a Stored Procedure name 
					// more than once during a single page execution cycle so check if it has already been set.
					if (AxpDataGrid1.StoredProcCommand == null)
						AxpDataGrid1.SQL = "GetTitles";
					else
						// clear any params that might have been set
						AxpDataGrid1.StoredProcCommand.Parameters.Clear();				

					// Set stored procedure parameters.
					if (pk != String.Empty)
						AxpDataGrid1.StoredProcCommand.Parameters.Add("title_id", pk);					// a single record
					else
						AxpDataGrid1.StoredProcCommand.Parameters.Add("title_id", -1);					// all records				
					break;
			}
		}

		// Custom database update routines

		private void InsertRecord()
		{
			try
			{
				OleDbCommand cmd = new OleDbCommand();
				cmd.Connection = new OleDbConnection(connectionString);
				// Sql Server 2000 and later:
				cmd.CommandText = "INSERT INTO titles (title, pub_id, anumber) VALUES (?,?,?)\nSelect SCOPE_IDENTITY()";
				cmd.Parameters.Add("title", AxpDataGrid1.GetUpdateValue("title"));
				cmd.Parameters.Add("pub_id", AxpDataGrid1.GetUpdateValue("pub_id"));
				cmd.Parameters.Add("anumber", AxpDataGrid1.GetUpdateValue("anumber"));
				cmd.Connection.Open();

				// Important!
				// Retrieve new primary key on Insert

				int newPrimaryKey = int.Parse(cmd.ExecuteScalar().ToString());
				cmd.Connection.Close();

				// Set grid data source to single record. 
				// This is needed to let the grid be able to display the record that was just Inserted.
				//		The record navigation bar will have its buttons disabled and show the text "Record 1 of 1"
				SetDataSource(newPrimaryKey.ToString());
			}
			catch
			{
				isInputValid = false;
			}
		}

		private void UpdateRecord()
		{
			try
			{
				OleDbCommand cmd = new OleDbCommand();
				cmd.Connection = new OleDbConnection(connectionString);
				cmd.CommandText = "UPDATE titles SET title=?, pub_id=?, anumber=? WHERE title_id=?";
				cmd.Parameters.Add("title", AxpDataGrid1.GetUpdateValue("title"));
				cmd.Parameters.Add("pub_id", AxpDataGrid1.GetUpdateValue("pub_id"));
				cmd.Parameters.Add("anumber", AxpDataGrid1.GetUpdateValue("anumber"));

				cmd.Parameters.Add("title_id", AxpDataGrid1.GetUpdateValue("title_id"));
				cmd.Connection.Open();
				cmd.ExecuteNonQuery();
				cmd.Connection.Close();
			}
			catch
			{
				isInputValid = false;
			}
		}

		private void DeleteRecord()
		{
			OleDbCommand cmd = new OleDbCommand();
			cmd.Connection = new OleDbConnection(connectionString);
			cmd.CommandText = "DELETE FROM titles WHERE title_id=?";
			cmd.Parameters.Add("title_id", AxpDataGrid1.GetUpdateValue("title_id"));
			cmd.Connection.Open();
			int affectedRows = cmd.ExecuteNonQuery();
			cmd.Connection.Close();

			// Important!
			// Set grid data source again, this will ensure that another record is displayed after the current was deleted.
			SetDataSource("");
		}

		private void AxpDataGrid1_BeforeFormEditRender(object sender, System.EventArgs e)
		{
			AxpDataGrid1.ShowPostedValues = !this.isInputValid;
			if (!this.isInputValid)
			{
				AxpDataGrid1.HeaderText = "<font color='red'><b>Invalid Data</b></font>";
				AxpDataGrid1.UpdateErrorMessage = "Please correct the errors.";
			}
			else
				AxpDataGrid1.UpdateMessage = "Data was saved to database";
		}

		private void AxpDataGrid1_InsertClick(object sender, System.EventArgs e)
		{
			InsertRecord();		
		}

		private void AxpDataGrid1_UpdateClick(object sender, System.EventArgs e)
		{
			UpdateRecord();
		}

		private void AxpDataGrid1_DeleteClick(object sender, System.EventArgs e)
		{
			DeleteRecord();
		}
	}
}
