Imports System.Configuration.ConfigurationManager

Partial Class Sample21b
	Inherits System.Web.UI.Page

	' 3 test types on this page	
	Private Enum TestTypes
		SQLCommand
		ManualDataSource
		StoredProcedure
	End Enum

	' >>>>>>>>>> Change testype here if needed <<<<<<<<<<<<<<
	Private testType As TestTypes = TestTypes.ManualDataSource
	Private connectionString As String

	Private isInputValid As Boolean = True

	' CREATE DATABASE Objects in Sql Server before testing this page.
	' 
	' Remove the comments and run in a SQL window:
	'
	' CREATE TABLE dbo.titles
	' (
	'    title_id  int         IDENTITY (1, 1) NOT NULL     CONSTRAINT PKtitleid PRIMARY KEY CLUSTERED,
	'    title     varchar(80) NULL,
  '    pub_id    char(4)     NULL,
	'    anumber   int         NULL
	' )
	' GO
	' 
	' CREATE PROCEDURE dbo.GetTitles
	'   @title_id int
	' as
	' if @title_id = -1
	' 	select * From titles
	' else
	' 	select * From titles where title_id=@title_id
	' GO	

	Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
		' Make sure to use an OleDb connection string (AxpDataGrid requires it, and we use OleDb for convenience in our custom routines below too.
    connectionString = ConfigurationManager.AppSettings("ConnectionString")

		AxpDataGrid1.EditOptions = "ALL NOVIEW"
		AxpDataGrid1.UseDataBinding = True		' Important, DataBind called in PreRender
		AxpDataGrid1.EditPerformUpdates = False		' We are doing our own database update 

		' Since editing is needed we MUST always provide a connection string
		' AND commands for the Edit Form, even if they are not used for Update,Insert and Delete
		AxpDataGrid1.ConnectionString = connectionString
		AxpDataGrid1.EditSQL = "Select * from titles"
		AxpDataGrid1.DeleteSQL = "Delete From titles"
		AxpDataGrid1.EditPrimaryKeys = "title_id"
		AxpDataGrid1.EditNewPKStatement = "autoincrement"

		' Display options
		AxpDataGrid1.RowRollOverEffect = True
		AxpDataGrid1.RowClickAction = "openform"
		AxpDataGrid1.DisplayNavBar = "both"

		' Set initial datasource to all records
		SetDataSource("")
	End Sub

	Protected Sub Page_PreRender(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.PreRender
	 AxpDataGrid1.DataBind()
	End Sub

	Private Sub SetDataSource(ByVal pk As String)
		' -------------------------------------------------
		' Tests for 3 different Grid datasource approaches
		' -------------------------------------------------

		' -------------------------------------------------
		' sqlCmd used for manual datasource and SQL command
		' -------------------------------------------------
		Dim sqlCmd As String = "SELECT * FROM titles"
		If pk <> String.Empty Then
			sqlCmd += " WHERE title_id=" + pk
		End If

		Select Case testType
			Case TestTypes.SQLCommand
				' -------------------------------------------------
				' >>> TEST 1. SQL command.
				' -------------------------------------------------
				AxpDataGrid1.SQL = sqlCmd

			Case TestTypes.ManualDataSource
				' -------------------------------------------------
				' >>> TEST 2. Manual DataSource.
				' -------------------------------------------------
				Dim da As New OleDb.OleDbDataAdapter(sqlCmd, connectionString)
				Dim dt As New DataTable
				da.Fill(dt)
				AxpDataGrid1.DataSource = dt

			Case TestTypes.StoredProcedure
				' -------------------------------------------------
				' >>> TEST 3. Sql Server Stored Procedure. 
				' -------------------------------------------------

				' AxpDataGrid does not support setting a Stored Procedure name 
				' more than once during a single page execution cycle so check if it has already been set.
				If AxpDataGrid1.StoredProcCommand Is Nothing Then
					AxpDataGrid1.SQL = "GetTitles"
				Else
					' clear any params that might have been set
					AxpDataGrid1.StoredProcCommand.Parameters.Clear()
				End If

				' Set stored procedure parameters.
				If pk <> String.Empty Then
					AxpDataGrid1.StoredProcCommand.Parameters.AddWithValue("title_id", pk)					' a single record
				Else
					AxpDataGrid1.StoredProcCommand.Parameters.AddWithValue("title_id", -1)					' all records
				End If

		End Select

	End Sub

	' Custom database update routines

	Private Sub InsertRecord()
		Try
			Dim cmd As New OleDb.OleDbCommand
			cmd.Connection = New OleDb.OleDbConnection(connectionString)
			' Sql Server 2000 and later:
			cmd.CommandText = "INSERT INTO titles (title, pub_id, anumber) VALUES (?,?,?)" + vbCrLf + "Select SCOPE_IDENTITY()"
			cmd.Parameters.AddWithValue("title", AxpDataGrid1.GetUpdateValue("title"))
			cmd.Parameters.AddWithValue("pub_id", AxpDataGrid1.GetUpdateValue("pub_id"))
			cmd.Parameters.AddWithValue("anumber", AxpDataGrid1.GetUpdateValue("anumber"))
			cmd.Connection.Open()

			' Important!
			' Retrieve new primary key on Insert

			Dim newPrimaryKey As Integer = Integer.Parse(cmd.ExecuteScalar().ToString())
			cmd.Connection.Close()

			' Set grid data source to single record. 
			' This is needed to let the grid be able to display the record that was just Inserted.
			'		The record navigation bar will have its buttons disabled and show the text "Record 1 of 1"
			SetDataSource(newPrimaryKey.ToString)
		Catch ex As Exception
			isInputValid = False
		End Try
	End Sub

	Private Sub UpdateRecord()
		Try
			Dim cmd As New OleDb.OleDbCommand
			cmd.Connection = New OleDb.OleDbConnection(connectionString)
			cmd.CommandText = "UPDATE titles SET title=?, pub_id=?, anumber=? WHERE title_id=?"
			cmd.Parameters.AddWithValue("title", AxpDataGrid1.GetUpdateValue("title"))
			cmd.Parameters.AddWithValue("pub_id", AxpDataGrid1.GetUpdateValue("pub_id"))
			cmd.Parameters.AddWithValue("anumber", AxpDataGrid1.GetUpdateValue("anumber"))

			cmd.Parameters.AddWithValue("title_id", AxpDataGrid1.GetUpdateValue("title_id"))
			cmd.Connection.Open()
			cmd.ExecuteNonQuery()
			cmd.Connection.Close()
		Catch ex As Exception
			isInputValid = False
		End Try
	End Sub

	Private Sub DeleteRecord()
		Dim cmd As New OleDb.OleDbCommand
		cmd.Connection = New OleDb.OleDbConnection(connectionString)
		cmd.CommandText = "DELETE FROM titles WHERE title_id=?"
		cmd.Parameters.AddWithValue("title_id", AxpDataGrid1.GetUpdateValue("title_id"))
		cmd.Connection.Open()
		Dim affectedRows As Integer = cmd.ExecuteNonQuery()
		cmd.Connection.Close()

		' Important!
		' Set grid data source again, this will ensure that another record is displayed after the current was deleted.
		SetDataSource("")
	End Sub

	Protected Sub AxpDataGrid1_BeforeFormEditRender(ByVal sender As Object, ByVal e As System.EventArgs) Handles AxpDataGrid1.BeforeFormEditRender
		AxpDataGrid1.ShowPostedValues = Not isInputValid
		If Not isInputValid Then
			AxpDataGrid1.HeaderText = "<font color='red'><b>Invalid Data</b></font>"
			AxpDataGrid1.UpdateErrorMessage = "Please correct the errors."
		Else
			AxpDataGrid1.UpdateMessage = "Data was saved to database"
		End If
	End Sub

	Protected Sub AxpDataGrid1_InsertClick(ByVal sender As Object, ByVal e As System.EventArgs) Handles AxpDataGrid1.InsertClick
		InsertRecord()
	End Sub

	Protected Sub AxpDataGrid1_UpdateClick(ByVal sender As Object, ByVal e As System.EventArgs) Handles AxpDataGrid1.UpdateClick
		UpdateRecord()
	End Sub

	Protected Sub AxpDataGrid1_DeleteClick(ByVal sender As Object, ByVal e As System.EventArgs) Handles AxpDataGrid1.DeleteClick
		DeleteRecord()
	End Sub

End Class
