Imports System.Configuration.ConfigurationManager

Partial Class Sample25
	Inherits System.Web.UI.Page

	Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
		AxpDataGrid1.ConnectionString = AppSettings("ConnectionString")
		' Setting Productname to a required field since the grid is unable to detect it on some Access databases
		Dim efi As Axezz.WebControls.EditFieldItem = New Axezz.WebControls.EditFieldItem
		efi.ColumnName = "ProductName"
		efi.Required = True
		AxpDataGrid1.SetEditField(efi)

		' This sample might seem a bit meaningless but it does show how the various events and methods can be used.....

		' A read only drop down always defaulting to 1 in BeforeInsertRecord/BeforeUpdateRecord
		AxpDataGrid1.AddEditLookup("SupplierId", "Suppliers", "SupplierId", "CompanyName", "2", True)
		Dim efi2 As Axezz.WebControls.EditFieldItem = New Axezz.WebControls.EditFieldItem
		efi2.ColumnName = "SupplierId"
		efi2.DefaultValue = 1
		efi2.IsReadOnly = True
		efi2.IsHardCoded = True		 ' needed when IsReadOnly = True and we want to alter/set the value in the BeforeInsertRecord/BeforeUpdateRecord
		AxpDataGrid1.SetEditField(efi2)

		' A hidden input field hard coded to 2 in BeforeInsertRecord/BeforeUpdateRecord
		Dim efi3 As Axezz.WebControls.EditFieldItem = New Axezz.WebControls.EditFieldItem
		efi3.ColumnName = "CategoryId"
		efi3.Visible = False
		AxpDataGrid1.SetEditField(efi3)
	End Sub

	Protected Sub AxpDataGrid1_BeforeInsertRecord(ByVal sender As Object, ByVal e As Axezz.WebControls.UpdateRecordEventArgs) Handles AxpDataGrid1.BeforeInsertRecord
		ValidateFields()
		SetHardCodedValues()
	End Sub

	Protected Sub AxpDataGrid1_BeforeUpdateRecord(ByVal sender As Object, ByVal e As Axezz.WebControls.UpdateRecordEventArgs) Handles AxpDataGrid1.BeforeUpdateRecord
		ValidateFields()
		SetHardCodedValues()
	End Sub

	
	''' <summary>
	''' General utility function to set an error message for a column
	''' </summary>
	Private Sub SetColumnErrorMessage(ByVal grid As Axezz.WebControls.AxpDataGrid, ByVal columnName As String, ByVal errorMessage As String)
		Dim exists As Boolean = False
		Dim i As Integer
		For i = 0 To grid.EditFields.Count - 1
			If grid.EditFields(i).ColumnName = columnName Then ' note - case sensitive comparison
				exists = True
				Exit For
			End If
		Next
		Dim efi As Axezz.WebControls.EditFieldItem
		If exists Then
			efi = grid.EditFields(i)
		Else
			efi = New Axezz.WebControls.EditFieldItem()
			efi.ColumnName = columnName
			AxpDataGrid1.SetEditField(efi)
		End If
		Dim s As String = String.Format("<span style=""font-weight:bold; color:red;"">{0}</span>", errorMessage)
		If Not efi.HtmlAfter Is Nothing AndAlso efi.HtmlAfter.Length = 0 Then
			efi.HtmlAfter = s
		Else
			efi.HtmlAfter = "&nbsp;" + s
		End If
	End Sub

	Private Sub ValidateFields()
		If Not AxpDataGrid1.UpdateFields("QuantityPerUnit") Is Nothing Then
			If AxpDataGrid1.UpdateFields("QuantityPerUnit").ColumnValue.Trim.Length > 0 Then
				Dim test As Integer = -1
				Try
					test = Integer.Parse(AxpDataGrid1.UpdateFields("QuantityPerUnit").ColumnValue)
				Catch
					AxpDataGrid1.AbortCommandExecution()

					' Testing a general utility function as defined above...
					SetColumnErrorMessage(AxpDataGrid1, "QuantityPerUnit", "Not a number")

					' The code below does the same manually for a single column, but will fail if the column already has an EditFieldItem defined.
					' Show error message below the input text field.

					'Dim edit1 As New Axezz.WebControls.EditFieldItem
					'With edit1
					'	.ColumnName = "QuantityPerUnit"
					'	.HtmlAfter = "<font color='red'><strong>&nbsp;Not a number</strong></font>"
					'End With
					'AxpDataGrid1.SetEditField(edit1)
				End Try
			End If
		End If
	End Sub

	Private Sub SetHardCodedValues()
		' Note! All UpdateFields must be present in the Select query. E.g. The column "CategoryId"
		If Not AxpDataGrid1.UpdateFields("SupplierId") Is Nothing Then
			AxpDataGrid1.UpdateFields("SupplierId").ColumnValue = "1"
		End If
		If Not AxpDataGrid1.UpdateFields("CategoryId") Is Nothing Then
			AxpDataGrid1.UpdateFields("CategoryId").ColumnValue = "2"
		End If
	End Sub
End Class
